==> opencascade_7.6.3+dfsg1.orig.tar.xz: occt-V7_6_3/src/StepAP203/StepAP203_CertifiedItem.cxx <==
// Created on: 1999-11-26
// Created by: Andrey BETENEV
// Copyright (c) 1999 Matra Datavision
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

// Generator:	ExpToCas (EXPRESS -> CASCADE/XSTEP Translator) V1.0

#include <Standard_Transient.hxx>
#include <StepAP203_CertifiedItem.hxx>
#include <StepRepr_SuppliedPartRelationship.hxx>

//=======================================================================
//function : StepAP203_CertifiedItem
//purpose  : 
//=======================================================================
StepAP203_CertifiedItem::StepAP203_CertifiedItem ()
{
}

//=======================================================================
//function : CaseNum
//purpose  : 
//=======================================================================

Standard_Integer StepAP203_CertifiedItem::CaseNum (const Handle(Standard_Transient)& ent) const
{
  if (ent.IsNull()) return 0;
  if (ent->IsKind(STANDARD_TYPE(StepRepr_SuppliedPartRelationship))) return 1;
  return 0;
}

//=======================================================================
//function : SuppliedPartRelationship
//purpose  : 
//=======================================================================

Handle(StepRepr_SuppliedPartRelationship) StepAP203_CertifiedItem::SuppliedPartRelationship () const
{
  return Handle(StepRepr_SuppliedPartRelationship)::DownCast(Value());
}

==> opencascade_7.9.2+dfsg.orig.tar.xz: occt-V7_9_2/src/StepAP203/StepAP203_CertifiedItem.cxx <==
// Created on: 1999-11-26
// Created by: Andrey BETENEV
// Copyright (c) 1999 Matra Datavision
// Copyright (c) 1999-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

// Generator:	ExpToCas (EXPRESS -> CASCADE/XSTEP Translator) V1.0

#include <Standard_Transient.hxx>
#include <StepAP203_CertifiedItem.hxx>
#include <StepRepr_SuppliedPartRelationship.hxx>

//=================================================================================================

StepAP203_CertifiedItem::StepAP203_CertifiedItem() {}

//=================================================================================================

Standard_Integer StepAP203_CertifiedItem::CaseNum(const Handle(Standard_Transient)& ent) const
{
  if (ent.IsNull())
    return 0;
  if (ent->IsKind(STANDARD_TYPE(StepRepr_SuppliedPartRelationship)))
    return 1;
  return 0;
}

//=================================================================================================

Handle(StepRepr_SuppliedPartRelationship) StepAP203_CertifiedItem::SuppliedPartRelationship() const
{
  return Handle(StepRepr_SuppliedPartRelationship)::DownCast(Value());
}
